pub fn generate(models_json_path: &Path) -> Result<GeneratedOutput, String>Expand description
Run the codegen, returning the generated Rust source and per-provider docs.
pub fn generate(models_json_path: &Path) -> Result<GeneratedOutput, String>Run the codegen, returning the generated Rust source and per-provider docs.